@@ -1,4 +1,4 @@
-/*	$OpenBSD: log.h,v 1.6 2002/02/22 12:20:34 markus Exp $	*/
+/*	$OpenBSD: log.h,v 1.7 2002/05/19 20:54:52 deraadt Exp $	*/
 
 /*
  * Author: Tatu Ylonen <ylo@cs.hut.fi>
@@ -28,7 +28,7 @@ typedef enum {
 	SYSLOG_FACILITY_LOCAL5,
 	SYSLOG_FACILITY_LOCAL6,
 	SYSLOG_FACILITY_LOCAL7,
-	SYSLOG_FACILITY_NOT_SET = -1,
+	SYSLOG_FACILITY_NOT_SET = -1
 }       SyslogFacility;
 
 typedef enum {
@@ -40,7 +40,7 @@ typedef enum {
 	SYSLOG_LEVEL_DEBUG1,
 	SYSLOG_LEVEL_DEBUG2,
 	SYSLOG_LEVEL_DEBUG3,
-	SYSLOG_LEVEL_NOT_SET = -1,
+	SYSLOG_LEVEL_NOT_SET = -1
 }       LogLevel;
 
 void     log_init(char *, LogLevel, SyslogFacility, int);
