@@ -12,7 +12,7 @@
  */
 
 #include "includes.h"
-RCSID("$OpenBSD: sshpty.c,v 1.4 2001/12/19 07:18:56 deraadt Exp $");
+RCSID("$OpenBSD: sshpty.c,v 1.7 2002/06/24 17:57:20 deraadt Exp $");
 
 #include <util.h>
 #include "sshpty.h"
@@ -225,9 +225,8 @@ pty_make_controlling_tty(int *ttyfd, const char *ttyname)
 	if (fd < 0)
 		error("open /dev/tty failed - could not set controlling tty: %.100s",
 		    strerror(errno));
-	else {
+	else
 		close(fd);
-	}
 }
 
 /* Changes the window size associated with the pty. */
@@ -237,6 +236,7 @@ pty_change_window_size(int ptyfd, int row, int col,
 	int xpixel, int ypixel)
 {
 	struct winsize w;
+
 	w.ws_row = row;
 	w.ws_col = col;
 	w.ws_xpixel = xpixel;
@@ -274,13 +274,13 @@ pty_setowner(struct passwd *pw, const char *ttyname)
 	if (st.st_uid != pw->pw_uid || st.st_gid != gid) {
 		if (chown(ttyname, pw->pw_uid, gid) < 0) {
 			if (errno == EROFS &&
-			   (st.st_uid == pw->pw_uid || st.st_uid == 0))
-				error("chown(%.100s, %d, %d) failed: %.100s",
-				    ttyname, pw->pw_uid, gid,
+			    (st.st_uid == pw->pw_uid || st.st_uid == 0))
+				error("chown(%.100s, %u, %u) failed: %.100s",
+				    ttyname, (u_int)pw->pw_uid, (u_int)gid,
 				    strerror(errno));
 			else
-				fatal("chown(%.100s, %d, %d) failed: %.100s",
-				    ttyname, pw->pw_uid, gid,
+				fatal("chown(%.100s, %u, %u) failed: %.100s",
+				    ttyname, (u_int)pw->pw_uid, (u_int)gid,
 				    strerror(errno));
 		}
 	}
